@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 
 import pymongo
-
+import time
 import logging
 import json
 import os
@@ -32,6 +32,7 @@ class mongodb(object):
         self.level = "info"
         self.is_login = False
         self.mechanism = "SCRAM-SHA-1"
+        self.timestamp = 0
         [setattr(self, k, v) for k,v in kwargs.items()]
         # self.login()
 
@@ -62,9 +63,18 @@ class mongodb(object):
         self.login()
         return self.conn[db].list_collection_names()
 
+    def not_timeout(self):
+        timestamp = time.time()
+        ret = self.timestamp <= timestamp <= (self.timestamp + 1800)
+        self.timestamp = timestamp
+        return ret
+
     def login(self):
         if self.is_login:
-            return True
+            if self.not_timeout()
+                return True
+            else:
+                log(f"{self}连接超时，强制重连")
         self.conn = pymongo.MongoClient("mongodb://{host}:{port}/".format(**self.__dict__))
         if self.user and self.passwd:
             auth = self.conn["admin"]
@@ -72,6 +82,7 @@ class mongodb(object):
         self._db = self.conn[self.db]
         self._table = self._db[self.table]
         self.is_login = True
+        self.timestamp = time.time()
         return True
 
     def drop(self):
